==> nextcloud-app-user-saml-7.1.0-1-x86_64.pkg.tar.zst: usr/share/webapps/nextcloud/apps/user_saml/l10n/et_EE.js <==
OC.L10N.register(
    "user_saml",
    {
    "Saved" : "Salvestatud",
    "Could not save" : "Ei õnnestunud salvestada",
    "Provider" : "Teenusepakkuja",
    "Provider %s" : "Teenusepakkuja %s",
    "X.509 certificate of the Service Provider" : "Teenusepakkuja X.509 sertifikaat",
    "Private key of the Service Provider" : "Teenusepakkuja privaatvõti",
    "Group A, Group B, …" : "Grupp A, grupp B, …",
    "Require membership in these groups, if any." : "Eelda nende gruppide liikmelisust, kui seda vaja peaks olema.",
    "Email address" : "E-posti aadress",
    "Encrypted" : "Krüptitud",
    "Use POST method for SAML request (default: GET)" : "Kasuta SAML-i päringute jaoks POST-meetodit (vaikimisi on kasutusel GET-meetod)",
    "SSO & SAML authentication" : "SSO & SAML autentimine",
    "Open documentation" : "Ava dokumentatsioon",
    "Use built-in SAML authentication" : "Kasuta sisse-ehitatud SAML autentimist",
    "Use environment variable" : "Kasuta keskonnamuutujat",
    "Global settings" : "Üldised seadistused",
    "Remove identity provider" : "Eemalda isikutuvastusteenuse pakkuja",
    "Add identity provider" : "Lisa isikutuvastusteenuse pakkuja",
    "General" : "Üldine",
    "Service Provider Data" : "Teenusepakkuja andmed",
    "Security settings" : "Turvaseaded",
    "Reset settings" : "Lähtesta seadistused",
    "Error" : "Viga",
    "JavaScript is disabled in your browser. Please enable it to continue." : "JavaScript on sinu veebibrauseris keelatud. Jätkamiseks palun luba JavaScripti kasutamine.",
    "Access denied." : "Ligipääs on keelatud."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-user-saml-7.1.1-1-x86_64.pkg.tar.zst: usr/share/webapps/nextcloud/apps/user_saml/l10n/et_EE.js <==
OC.L10N.register(
    "user_saml",
    {
    "Saved" : "Salvestatud",
    "Could not save" : "Ei õnnestunud salvestada",
    "Provider" : "Teenusepakkuja",
    "Provider %s" : "Teenusepakkuja %s",
    "X.509 certificate of the Service Provider" : "Teenusepakkuja X.509 sertifikaat",
    "Private key of the Service Provider" : "Teenusepakkuja privaatvõti",
    "Group A, Group B, …" : "Grupp A, grupp B, …",
    "Require membership in these groups, if any." : "Eelda nende gruppide liikmelisust, kui seda vaja peaks olema.",
    "Email address" : "E-posti aadress",
    "Encrypted" : "Krüptitud",
    "Unspecified" : "Määratlemata",
    "Use POST method for SAML request (default: GET)" : "Kasuta SAML-i päringute jaoks POST-meetodit (vaikimisi on kasutusel GET-meetod)",
    "SSO & SAML authentication" : "SSO & SAML autentimine",
    "Open documentation" : "Ava dokumentatsioon",
    "Use built-in SAML authentication" : "Kasuta sisse-ehitatud SAML autentimist",
    "Use environment variable" : "Kasuta keskonnamuutujat",
    "Global settings" : "Üldised seadistused",
    "Remove identity provider" : "Eemalda isikutuvastusteenuse pakkuja",
    "Add identity provider" : "Lisa isikutuvastusteenuse pakkuja",
    "General" : "Üldine",
    "Service Provider Data" : "Teenusepakkuja andmed",
    "Security settings" : "Turvaseaded",
    "Signatures and encryption offered" : "Allkirjastamine ja krüptimine on saadaval",
    "Signatures and encryption required" : "Allkirjastamine ja krüptimine on nõutavad",
    "User filtering" : "Kasutajate filtreerimine",
    "Download metadata XML" : "Laadi alla metateabe XML",
    "Reset settings" : "Lähtesta seadistused",
    "Metadata invalid" : "Vigane metateave",
    "Metadata valid" : "Metateave on korrektne",
    "Error" : "Viga",
    "JavaScript is disabled in your browser. Please enable it to continue." : "JavaScript on sinu veebibrauseris keelatud. Jätkamiseks palun luba JavaScripti kasutamine.",
    "Access denied." : "Ligipääs on keelatud.",
    "Login options:" : "Sisselogimise valikud:",
    "Choose an authentication provider" : "Vali autentimise teenusepakkuja"
},
"nplurals=2; plural=(n != 1);");
